# What's this?
pyDeutscheBahn is a collection of utilities related to German train operator Deutsche Bahn.
It includes bindings for [db-fakedisplay](https://github.com/derf/db-fakedisplay), coach order API, list of stations, and more.

Includes unmodified DS 100 station data, licensed under [CC BY 4.0](https://creativecommons.org/licenses/by/4.0), created by Deutsche Bahn AG.

# Installation
`pip install deutschebahn`